pub fn list_groups(opts: &DispatchOpts) -> Result<Vec<String>, DispatchError>Expand description
Return all distinct group names present in the config, sorted.
pub fn list_groups(opts: &DispatchOpts) -> Result<Vec<String>, DispatchError>Return all distinct group names present in the config, sorted.