pub fn run_in_group(
group: &str,
name: &str,
opts: &DispatchOpts,
) -> Result<DispatchReport, DispatchError>Expand description
Run the named command in the given group using production process/notify/prompt implementations.
pub fn run_in_group(
group: &str,
name: &str,
opts: &DispatchOpts,
) -> Result<DispatchReport, DispatchError>Run the named command in the given group using production process/notify/prompt implementations.