Module doctor

Module doctor 

krypt doctor — diagnostic health-check for an install.

Collects a set of named checks into a DoctorReport struct, each represented by a CheckStatus that can be Ok, Warn, Fail, or NotApplicable. The report is serde-serializable for --json output and has a human-readable DoctorReport::render_text method.

Entry point: doctor.

Structs

DoctorOpts
Inputs to doctor.
DoctorReport
Summary of every diagnostic check.

Enums

CheckStatus
Result of a single diagnostic check.

Functions

doctor
Run all diagnostic checks and return a DoctorReport.