IncludeError

Enum IncludeError 

pub enum IncludeError {
    Config(ConfigError),
    Io {
        path: PathBuf,
        source: Error,
    },
    Cycle {
        chain: String,
    },
    DepthExceeded {
        max: usize,
        last: PathBuf,
    },
    Glob {
        pattern: String,
        base: PathBuf,
        reason: String,
    },
}
Errors that can arise during include expansion.

Variants



Config(ConfigError)

A parse or validation error in one of the included files.



Io

Could not read a file that matched a glob.

Fields

path: PathBuf

The file we failed to read.

source: Error

Underlying OS error.



Cycle

A file was reachable from itself through the include chain.

Fields

chain: String

Human-readable a -> b -> a chain.



DepthExceeded

The include chain exceeded [DEFAULT_MAX_DEPTH] hops.

Fields

max: usize

The limit that was hit.

last: PathBuf

The file that would have been the next hop.



Glob

A glob pattern was syntactically invalid.

Fields

pattern: String

The raw pattern string from the config.

base: PathBuf

Directory the pattern was relative to.

reason: String

Human-readable error from the glob crate.