pub fn init(opts: &InitOpts) -> Result<InitReport, InitError>Expand description
Initialise a dotfiles repo and write the tool config.
pub fn init(opts: &InitOpts) -> Result<InitReport, InitError>Initialise a dotfiles repo and write the tool config.