DispatchError

Enum DispatchError 

pub enum DispatchError {
    ConfigLoad(Box<IncludeError>),
    GroupNotFound {
        name: String,
        available: Vec<String>,
    },
    CommandNotFound {
        group: String,
        name: String,
        available_in_group: Vec<String>,
    },
    PlatformMismatch {
        group: String,
        name: String,
        required: String,
        current: String,
    },
    Runner(Box<RunnerError>),
}
Everything that can go wrong in the dispatch subsystem.

Boxed large variants to stay ≤ 128 bytes on all targets.

Variants



ConfigLoad(Box<IncludeError>)

The config file could not be loaded or parsed.



GroupNotFound

No [[command]] entries exist for the requested group.

Fields

name: String

The group name that was looked up.

available: Vec<String>

All groups defined in the config.



CommandNotFound

No [[command]] group = "<group>" entry matched the requested name.

Fields

group: String

The group being searched.

name: String

The name that was looked up.

available_in_group: Vec<String>

All command names defined in the group (regardless of platform).



PlatformMismatch

The requested command exists but is restricted to a different platform.

Fields

group: String

Group name.

name: String

Command name.

required: String

Platform the command requires.

current: String

Platform the binary is running on.



Runner(Box<RunnerError>)

The step runner returned an error.